.. _evaluation:

Synthetic Data Evaluation
=========================

A very common question when someone starts using **SDV** to generate
synthetic data is: *"How good is the data that I just generated?"*

In order to answer this question, **SDV** has a collection of metrics
and tools that allow you to compare the *real* that you provided and the
*synthetic* data that you generated using **SDV** or any other tool.

In the followin guides we will show you how to perform this evaluation and
how to explore the different metrics that exist.

.. toctree::
    :titlesonly:

    evaluation_framework
    synthetic_data_metrics
